@@ -30,7 +30,7 @@ public:
     virtual ~ClipboardInterface() {}
     virtual QListWidget* getClipbaordListWidget() = 0;
     virtual SidebarClipBoardSignal* createClipSignal() = 0;
-    virtual QGroupBox* getClipbaordGroupBox() = 0;
+    virtual QWidget* getClipbaordGroupBox() = 0;
 };
 #define ClipboardInterface_iid "org.ukui.sidebar-qt.plugin-iface.ClipboardInterface"
 Q_DECLARE_INTERFACE(ClipboardInterface, ClipboardInterface_iid)
