@@ -29,7 +29,8 @@ static PluginManager *global_instance = nullptr;
 
 PluginManager::PluginManager(QObject *parent) : QObject(parent)
 {
-    QDir pluginsDir("/usr/lib/ukui-sidebar/sidebarSmallPlugins");
+    QString plugins_path(PLUGIN_INSTALL_DIRS);
+    QDir pluginsDir(plugins_path + "/sidebarSmallPlugins");
     pluginsDir.setFilter(QDir::Files);
 
     qDebug()<<pluginsDir.entryList().count();
@@ -41,21 +42,17 @@ PluginManager::PluginManager(QObject *parent) : QObject(parent)
         qDebug() << pluginLoader.load();
         qDebug() << pluginLoader.errorString();
         QObject *pPlugin = pluginLoader.instance();
-        if (!pPlugin) {
+        if (!pPlugin)
             continue;
-        }
-        qDebug()<<"test start";
         PluginInterface *pPluginInterface = dynamic_cast<PluginInterface*>(pPlugin);
-        if (!pPluginInterface) {
+        if (!pPluginInterface)
             continue;
-        }
 
         qDebug()<<pPluginInterface->name();
         m_PluginInterfaceHash.insert(pPluginInterface->name(), pPluginInterface);
         switch (pPluginInterface->pluginType()) {
             case PluginInterface::SmallPlugin: {
                 /* Plugins Num++, add Hash SmallPlugins pPluginInterface-->SmallPluginsInterface */
-                qDebug() << "Plugins Num++, add Hash SmallPlugins pPluginInterface-->SmallPluginsInterface";
                 SidebarSmallPluginInterface *p_SmallPluginsInterface = dynamic_cast<SidebarSmallPluginInterface*>(pPluginInterface);
                 SmallPluginsManage::getInstance()->registerSmallplugin(pPluginInterface, p_SmallPluginsInterface);
                 break;
@@ -79,9 +76,8 @@ PluginManager::~PluginManager()
 
 PluginManager *PluginManager::getInstance()
 {
-    if (!global_instance) {
+    if (!global_instance)
         global_instance = new PluginManager;
-    }
     return global_instance;
 }
 
