@@ -20,97 +20,95 @@
 #include "widget.h"
 #include "notification_interface.h"
 #include "pluginmanage.h"
-#include "realtimepropertyanimation.h"
 #include "sidebarpluginswidgets.h"
 #include <stdio.h>
 #include <QtDBus>
+#include <QGuiApplication>
 #include "customstyle.h"
 
+double tranSparency = 0.7;
 
 Widget::Widget(QWidget *parent) : QWidget (parent)
 {
     m_pTranslator = new QTranslator;
-    QLocale locale;
-    if( locale.language() == QLocale::Chinese )  //获取系统语言环境
-    {
-        m_pTranslator->load(QString(":sidebartranslat/Sidebar_zh_CN.qm"));  //选择翻译文件
+    if (m_pTranslator->load(QLocale(), QLatin1String("ukui-sidebar"), QLatin1String("_"), QLatin1String("/usr/share/ukui-sidebar")))
         QApplication::installTranslator(m_pTranslator);
-    }
+    else
+        qDebug() << "cannot load translator " << QLocale::system().name() << ".qm!";
     m_bShowFlag = false;
-    m_bFwinkleFlag = true;
-
-    //监听屏幕分辨率是否变化
-    m_pDeskWgt = QApplication::desktop();
-//    qDebug() << "dasdasdas" << m_pDeskWgt->width();
-//    qDebug() << "dasdasdas" << m_pDeskWgt->height();
-    connect(m_pDeskWgt, SIGNAL(resized(int)), this, SLOT(onResolutionChanged(int)));
-    connect(m_pDeskWgt, &QDesktopWidget::primaryScreenChanged, this, &Widget::primaryScreenChangedSLot);
-    connect(m_pDeskWgt, &QDesktopWidget::screenCountChanged, this, &Widget::screenCountChangedSlots);
+    m_bClipboardFlag = true;
 
+    /* 链接任务栏Dbus接口，获取任务栏高度和位置 */
     m_pServiceInterface = new QDBusInterface(PANEL_DBUS_SERVICE, PANEL_DBUS_PATH, PANEL_DBUS_INTERFACE, QDBusConnection::sessionBus());
     m_pServiceInterface->setTimeout(2147483647);
 
-    //主界面最外框布局器
-    m_pMainOuterBoxLayout = new QVBoxLayout;
-    m_pMainOuterBoxLayout->setContentsMargins(0,0,0,0);
-    m_pMainOuterBoxLayout->setSpacing(0);
+    /* 链接任务栏Dbus接口，获取任务栏点击信号 */
+    QDBusConnection::sessionBus().connect(QString(), QString("/taskbar/click"), \
+                                          "com.ukui.panel.plugins.taskbar", "sendToUkuiDEApp", this, SLOT(ClickPanelHideSidebarSlots(void)));
 
-    //主界面最外框架部件
-    m_pMainOuterWidget = new QWidget(this);
-    m_pMainOuterWidget->setStyleSheet("QWidget#MainOuterWidget{background:rgba(255, 255, 0, 0);}");
-    m_pMainOuterReplaceWidget = new QWidget(this);
-    m_pMainOuterReplaceWidget->setStyleSheet("background:transparent;");
-    m_pMainOuterReplaceWidget->setVisible(false);
+    /* 链接任务栏dgsetting接口 */
+    if(QGSettings::isSchemaInstalled(UKUI_PANEL_SETTING))
+        m_pPanelSetting = new QGSettings(UKUI_PANEL_SETTING);
 
-    //主界面显示
+    /* 监听屏幕分辨率是否变化 主频是否有变化 初始化屏幕宽高 和主屏起始X坐标值 */
+    m_pDeskWgt = QApplication::desktop();
+//    connect(m_pDeskWgt, SIGNAL(resized(int)), this, SLOT(onResolutionChanged(int)));
+    connect(QApplication::primaryScreen(), &QScreen::geometryChanged, this, &Widget::onResolutionChanged);
+    connect(m_pDeskWgt, &QDesktopWidget::primaryScreenChanged, this, &Widget::primaryScreenChangedSLot);
+    connect(m_pDeskWgt, &QDesktopWidget::screenCountChanged, this, &Widget::screenCountChangedSlots);
+
+    InitializeHomeScreenGeometry();  /* 初始化主屏的X坐标 */
+    GetsAvailableAreaScreen();       /* 获取屏幕可用高度区域 */
+
+    /* 主界面显示 */
     m_pMainQVBoxLayout = new QVBoxLayout;
-    m_pMainQVBoxLayout->setContentsMargins(0,0,0,0);
+    m_pMainQVBoxLayout->setContentsMargins(0, 0, 0, 0);
     m_pMainQVBoxLayout->setSpacing(0);
 
     /* 初始化剪贴板与小插件界面 */
     sidebarPluginsWidgets::initPluginsWidgets();
     sidebarPluginsWidgets::getInstancePluinsWidgets()->loadSmallPlugins();
 
-    InitializeHomeScreenGeometry();
-
-    //加载通知中心插件
-    if (false == loadNotificationPlugin()) {
+    /* 加载通知中心插件 */
+    if (false == loadNotificationPlugin())
         qDebug() << "通知中心插件加载失败";
-    }
 
-    //加载剪贴板插件, 将剪贴板插件加入到sidebarPluginsWidgets的GroupBox中
-    if (ListenClipboardSignal()) {
+    /* 加载剪贴板插件, 将剪贴板插件加入到sidebarPluginsWidgets的GroupBox中 */
+    if (ListenClipboardSignal())
         qDebug() << "剪贴板插件加载失败";
-    }
 
-    m_pMainOuterWidget->setLayout(m_pMainQVBoxLayout);
-//    this->setLayout(m_pMainOuterBoxLayout);
     this->setLayout(m_pMainQVBoxLayout);
 
-    //系统托盘栏显示
+    /* 系统托盘栏显示 */
     createAction();
     createSystray();
-    setIcon(TRAY_ICON);
+    setIcon(QIcon::fromTheme("kylin-tool-box", QIcon(TRAY_ICON)));
 
-    //安装事件过滤器
+    /* 安装事件过滤器 */
     installEventFilter(this);
 
     m_pAnimationShowSidebarWidget = new QPropertyAnimation(this, "geometry");
     m_pAnimationHideSidebarWidget = new QPropertyAnimation(this, "geometry");
 
     connect(m_pAnimationHideSidebarWidget, &QPropertyAnimation::finished, this, &Widget::hideAnimationFinish);
-    connect(m_pAnimationShowSidebarWidget, &QPropertyAnimation::finished, this, &Widget::showAnimationFinish);
     connect(m_pAnimationShowSidebarWidget, &QPropertyAnimation::valueChanged, this, &Widget::showAnimationAction);
+    connect(m_pAnimationShowSidebarWidget, &QPropertyAnimation::finished, this, &Widget::showAnimationFinish);
 
-    //将托盘栏图标和widget联系起来
+    /* 将托盘栏图标和widget联系起来 */
     connect(trayIcon, &QSystemTrayIcon::activated, this, &Widget::iconActivated);
     trayIcon->setVisible(true);
 
+    if (QGSettings::isSchemaInstalled(UKUI_TRANSPARENCY_SETTING)) {
+        qDebug() << "分配gsetting值";
+        m_pTransparency = new QGSettings(UKUI_TRANSPARENCY_SETTING);
+//        connect(m_pTransparency, &QGSettings::changed, this, &sidebarPluginsWidgets::getTransparencyValue);
+    }
+
     this->setWindowFlags(Qt::FramelessWindowHint | Qt::X11BypassWindowManagerHint);
     qInfo() << "---------------------------主界面加载完毕---------------------------";
 
-    m_pTimer = new QTimer();
-    connect(m_pTimer, SIGNAL(timeout()), this, SLOT(twinkle()));
+    m_pUpdateSmallPluginsWidget = new QTimer();
+    connect(m_pUpdateSmallPluginsWidget, &QTimer::timeout, this, &Widget::updateSmallPluginsClipboardWidget);
 }
 
 Widget::~Widget()
@@ -121,55 +119,72 @@ Widget::~Widget()
 //加载通知中心插件
 bool Widget::loadNotificationPlugin()
 {
-    QDir pluginsDir("/usr/lib/ukui-sidebar/notification");
+    QDir pluginsDir;
+    static bool installed = (QCoreApplication::applicationDirPath() == QDir(("/usr/bin")).canonicalPath());
+
+    if (installed)
+        pluginsDir = QDir(PLUGIN_INSTALL_DIRS);
+    else
+        pluginsDir = QDir(qApp->applicationDirPath() + "/plugins/ukui-sidebar-notification");
+
+    pluginsDir.setFilter(QDir::Files);
     QPluginLoader pluginLoader(pluginsDir.absoluteFilePath("libnotification_plugin.so"));
 
     m_pNotificationPluginObject = pluginLoader.instance();
-    if(nullptr == m_pNotificationPluginObject)
-    {
+    if(nullptr == m_pNotificationPluginObject) {
         return false;
     }
 
     NotificationInterface* pNotificationPluginObject = qobject_cast<NotificationInterface*>(m_pNotificationPluginObject);
-    if(nullptr == pNotificationPluginObject)
-    {
+    if(nullptr == pNotificationPluginObject) {
         return false;
     }
-
+    QWidget *widget = pNotificationPluginObject->centerWidget();
+    QString sheet = QString("QWidget{background-color:rgba(19,19,20,%1);}").arg(tranSparency);
+    widget->setStyleSheet(sheet);
     connect(m_pNotificationPluginObject, SIGNAL(Sig_onNewNotification()), this, SLOT(onNewNotification()));
     m_pMainQVBoxLayout->addWidget(pNotificationPluginObject->centerWidget(), 1);
-
     return true;
 }
 
 //加载剪贴板插件
 int Widget::ListenClipboardSignal()
 {
-    QDir pluginsDir("/usr/lib/ukui-sidebar/sidebar_clipboardPlugin_plugins");
-    pluginsDir.setFilter(QDir::Files);
+    QDir pluginsDir;
+    static bool installed = (QCoreApplication::applicationDirPath() == QDir(("/usr/bin")).canonicalPath());
 
+    if (installed)
+        pluginsDir = QDir(PLUGIN_INSTALL_DIRS);
+    else
+        pluginsDir = QDir(qApp->applicationDirPath() + "/plugins/ukui-sidebar-clipboard");
+
+    pluginsDir.setFilter(QDir::Files);
     QPluginLoader pluginLoader(pluginsDir.absoluteFilePath("libclipboardPlugin.so"));
     QObject *pClipPlugin = pluginLoader.instance();
 
-    m_pSidebarClipboard = dynamic_cast<ClipboardInterface *>(pClipPlugin);                     //获取剪贴版插件指针;
+    m_pSidebarClipboard = dynamic_cast<ClipboardInterface *>(pClipPlugin);                          /* 获取剪贴版插件指针; */
 
     if (nullptr == m_pSidebarClipboard) {
         qWarning() << "剪贴板插件插件加载失败";
         return 1;
     }
-    m_pSidebarSignal = m_pSidebarClipboard->createClipSignal();                                     //获取剪贴板的信号类指针
+    m_pSidebarSignal = m_pSidebarClipboard->createClipSignal();                                     /* 获取剪贴板的信号类指针 */
     /* 点击剪贴板空白区域时，隐藏侧边栏 */
     connect(m_pSidebarSignal, &SidebarClipBoardSignal::ClipboardHideSignal, this, [=]() {
         mostGrandWidget::getInstancemostGrandWidget()->topLevelWidget()->setProperty("blurRegion", QRegion(QRect(1, 1, 1, 1)));
         hideAnimation();
     });
 
-    sidebarPluginsWidgets::getInstancePluinsWidgets()->m_pClipboardWidget = m_pSidebarClipboard->getClipbaordGroupBox();   //获取剪贴板的Groubox指针;
-    GetsAvailableAreaScreen();                                                                     //获取屏幕可用高度区域
+    connect(m_pSidebarSignal, &SidebarClipBoardSignal::CLipBoardEditConfirmButtonSignal, this, &Widget::ClipboardHideSlots);
+
+    connect(m_pSidebarSignal, &SidebarClipBoardSignal::ClipBoardWidgetEntryEditButtonSignal, this, &Widget::ClipboardShowSlots);
+
+    sidebarPluginsWidgets::getInstancePluinsWidgets()->m_pClipboardWidget = m_pSidebarClipboard->getClipbaordGroupBox();   /* 获取剪贴板的Widget指针; */
+    sidebarPluginsWidgets::getInstancePluinsWidgets()->initCliboardAnimation();                     /* 初始化剪贴板动画 */
     int clipboardhight = setClipBoardWidgetScaleFactor();
     qDebug() << "剪贴板高度" << clipboardhight;
-    sidebarPluginsWidgets::getInstancePluinsWidgets()->setClipboardWidgetSize(clipboardhight); //设定剪贴板高度
-    sidebarPluginsWidgets::getInstancePluinsWidgets()->AddPluginWidgetInterface();       //将下半部分所有控件加入到sidebarPluginsWidgets中
+    sidebarPluginsWidgets::getInstancePluinsWidgets()->setClipboardWidgetSize(clipboardhight);      /* 设定剪贴板高度 */
+    sidebarPluginsWidgets::getInstancePluinsWidgets()->AddPluginWidgetInterface();                  /* 将下半部分所有控件加入到sidebarPluginsWidgets中 */
     m_pMainQVBoxLayout->addWidget(sidebarPluginsWidgets::getInstancePluinsWidgets(), 0);
     return 0;
 }
@@ -177,38 +192,28 @@ int Widget::ListenClipboardSignal()
 //创建动作
 void Widget::createAction()
 {
-    minimizeAction = new QAction(tr("Mi&nimize"), this);
-    connect(minimizeAction, &QAction::triggered, this, &QWidget::hide);
+    Open = new QAction(QObject::tr("Open"), this);
+    connect(Open, &QAction::triggered, this, &Widget::OpenSidebarSlots);
 
-    maximizeAction = new QAction(tr("Ma&ximize"), this);
-    connect(maximizeAction, &QAction::triggered, this, &QWidget::showMaximized);
-
-    restoreAction = new QAction(tr("normal"), this);
-    connect(restoreAction, &QAction::triggered, this, &QWidget::showNormal);
-
-    quitAction = new QAction(tr("&Quit"), this);
-    connect(quitAction, &QAction::triggered, qApp, &QCoreApplication::quit);
+    OpenSetUp = new QAction(QIcon::fromTheme("application-menu", QIcon(SETTING_ICON)), QObject::tr("Set up notification center"), this);
+    connect(OpenSetUp, &QAction::triggered, this, &Widget::OpenControlCenterSettings);
 }
 
 //添加动作和创建 systray实例
 void Widget::createSystray()
 {
     trayIconMenu = new QMenu(this);
-    if (trayIconMenu == nullptr)
-    {
+    trayIconMenu->setProperty("iconHighlightEffectMode", 1);
+    if (trayIconMenu == nullptr) {
         qWarning() << "分配空间trayIconMenu失败";
         return ;
     }
-//    trayIconMenu->addAction(minimizeAction);
-//    trayIconMenu->addAction(maximizeAction);
-//    trayIconMenu->addAction(restoreAction);
-//    trayIconMenu->addSeparator();
-//    trayIconMenu->addAction(quitAction);
+    trayIconMenu->addAction(Open);
+    trayIconMenu->addAction(OpenSetUp);
 
     trayIcon = new QSystemTrayIcon(this);
 
-    if (nullptr == trayIcon)
-    {
+    if (nullptr == trayIcon) {
         qWarning()<< "分配空间trayIcon失败";
         return ;
     }
@@ -216,9 +221,8 @@ void Widget::createSystray()
 }
 
 //设置托盘栏的图标
-void Widget::setIcon(QString strIcon)
+void Widget::setIcon(QIcon icon)
 {
-    QIcon icon = QIcon(strIcon);
     trayIcon->setIcon(icon);
     setWindowIcon(icon);
     trayIcon->setToolTip(tr("Sidebar"));
@@ -227,106 +231,104 @@ void Widget::setIcon(QString strIcon)
 //设置activated信号
 void Widget::iconActivated(QSystemTrayIcon::ActivationReason reason)
 {
+    //获取透明度
+    if (QGSettings::isSchemaInstalled(UKUI_TRANSPARENCY_SETTING)){
+        if (m_pTransparency->keys().contains("transparency")) {
+            tranSparency = m_pTransparency->get("transparency").toDouble();
+        }
+    }
+    qDebug() << "获取的透明度为:" << tranSparency;
     switch (reason) {
-        case QSystemTrayIcon::Trigger:
-        {
+        case QSystemTrayIcon::Trigger: {
             if (m_bShowFlag) {
-                qDebug() << "Widget::iconActivated 隐藏";
                 mostGrandWidget::getInstancemostGrandWidget()->topLevelWidget()->setProperty("blurRegion", QRegion(QRect(1, 1, 1, 1)));
                 hideAnimation();
             } else {
                 mostGrandWidget::getInstancemostGrandWidget()->hide();
                 MostGrandWidgetCoordinates();
-                qDebug() << "Widget::iconActivated 展开";
                 mostGrandWidget::getInstancemostGrandWidget()->show();
                 showAnimation();
                 m_bShowFlag = true;
-                m_pTimer->stop();                               //当侧边栏展开时，停止闪烁定时器，并且设置有图标的托盘图标
-                setIcon(TRAY_ICON);
+                setIcon(QIcon::fromTheme("kylin-tool-box", QIcon(TRAY_ICON)));
             }
             break;
         }
-//        case QSystemTrayIcon::DoubleClick:
-//        {
-//            mostGrandWidget::getInstancemostGrandWidget()->hide();
-//            MostGrandWidgetCoordinates();
-//            qDebug() << "Widget::iconActivated 展开";
-//            mostGrandWidget::getInstancemostGrandWidget()->show();
-//            showAnimation();
-//            m_bShowFlag = true;
-//            m_pTimer->stop();                                   //当侧边栏展开时，停止闪烁定时器，并且设置有图标的托盘图标
-//            setIcon(TRAY_ICON);
-//            break;
-//        }
-        default:
-            break;
+    case QSystemTrayIcon::Context:
+        if (m_bShowFlag) {
+            trayIconMenu->hide();  //先隐藏菜单栏，不让其显示出来， 然后将sidebar隐藏
+            mostGrandWidget::getInstancemostGrandWidget()->topLevelWidget()->setProperty("blurRegion", QRegion(QRect(1, 1, 1, 1)));
+            hideAnimation();
+        }
+        break;
+   default:
+        break;
     }
 }
 
 //链接任务栏dbus获取高度的接口
 int Widget::connectTaskBarDbus()
 {
-    QDBusMessage msg = m_pServiceInterface->call("GetPanelSize", QVariant("Hight"));
-    int panelHight = msg.arguments().at(0).toInt();
-    return panelHight;
+    int panelHeight = 46;
+    if (m_pPanelSetting != nullptr) {
+        QStringList keys = m_pPanelSetting->keys();
+        if (keys.contains("panelsize")) {
+            panelHeight = m_pPanelSetting->get("panelsize").toInt();
+        }
+    } else {
+        QDBusMessage msg = m_pServiceInterface->call("GetPanelSize", QVariant("Hight"));
+        panelHeight = msg.arguments().at(0).toInt();
+        return panelHeight;
+    }
+    return panelHeight;
 }
 
 //获取任务栏状态位置下上左右
 int Widget::getPanelSite()
 {
-    QDBusMessage msg = m_pServiceInterface->call("GetPanelPosition", QVariant("Site"));
-    int PanelSite = msg.arguments().at(0).toInt();
-    qDebug() << "panel所在的位置" << PanelSite;
-    return PanelSite;
-}
-
-void Widget::mousePressEvent(QMouseEvent *event)
-{
-    if (event->buttons() == Qt::LeftButton)
-    {
-        mostGrandWidget::getInstancemostGrandWidget()->topLevelWidget()->setProperty("blurRegion", QRegion(QRect(1, 1, 1, 1)));
-        hideAnimation();
+    int panelPosition = 0;
+    if (m_pPanelSetting != nullptr) {
+        QStringList keys = m_pPanelSetting->keys();
+        if (keys.contains("panelposition")) {
+            panelPosition = m_pPanelSetting->get("panelposition").toInt();
+        }
+    } else {
+        QDBusMessage msg = m_pServiceInterface->call("GetPanelPosition", QVariant("Site"));
+        panelPosition = msg.arguments().at(0).toInt();
     }
+    qDebug() << "panel所在的位置" << panelPosition;
+    return panelPosition;
 }
 
 //获取屏幕的可用区域高度和宽度
 void Widget::GetsAvailableAreaScreen()
 {
     //如果取不到任务栏的高度,还是优先获取桌面分辨率,可用区域
-    if((0 == connectTaskBarDbus()) && (0 == getPanelSite()))
-    {
+    if ((0 == connectTaskBarDbus()) && (0 == getPanelSite())) {
         QScreen* pScreen = QGuiApplication::primaryScreen();
         QRect DeskSize = pScreen->availableGeometry();
         m_nScreenWidth = DeskSize.width();                      //桌面分辨率的宽
         m_nScreenHeight = DeskSize.height();                    //桌面分辨率的高
-    }
-    else
-    {
+    } else {
         //如果取到任务栏的高度,则取屏幕分辨率的高度
         QRect screenRect = m_pDeskWgt->screenGeometry();
         m_nScreenWidth = screenRect.width();
         m_nScreenHeight = screenRect.height();
     }
+    qDebug() << "主屏Width  --> " << m_nScreenWidth;
+    qDebug() << "主屏Height --> " << m_nScreenHeight;
 }
 
 /* 设定剪贴板高度 */
 int Widget::setClipBoardWidgetScaleFactor()
 {
-    int x , y;
-    x = m_nScreenWidth;
-    y = m_nScreenHeight;
-    if ((x >= 800 && x <= 1280)&&(y >= 600 && y <= 768)) {
-        qDebug() << "800 <= x <= 1280 && 600 <= y <= 720 ";
-        return m_nScreenHeight/2 - connectTaskBarDbus();
-    } else if ((x >= 1280 && x <= 2048)&&(y >= 900 && y <= 1080)) {
-        qDebug() << "1280 <= x <= 2048 && 900 <= y <= 1080";
+    if (m_nScreenHeight >= 600 && m_nScreenHeight <= 768) {
+        return m_nScreenHeight/2 - connectTaskBarDbus() - 60;
+    } else if (m_nScreenHeight >= 900 && m_nScreenHeight <= 1080) {
         return m_nScreenHeight/3;
-    } else if ((x >= 1920 && x <= 3840)&&(y >= 1200 && y <= 2160)) {
-        qDebug() << "1920 <= x 3840 && y >= 1200 && y <= 2160";
+    } else if (m_nScreenHeight >= 1200 && m_nScreenHeight <= 2160) {
         return m_nScreenHeight/4;
     } else {
         return m_nScreenHeight/2 - connectTaskBarDbus();
-        qDebug() << "y <= 600 || y>= 2160";
     }
 }
 
@@ -334,14 +336,15 @@ int Widget::setClipBoardWidgetScaleFactor()
 void Widget::showAnimation()
 {
     NotificationInterface* pNotificationPluginObject = qobject_cast<NotificationInterface*>(m_pNotificationPluginObject);
-    if(nullptr != pNotificationPluginObject)
-    {
+    if (nullptr != pNotificationPluginObject && false == m_bfinish)
         pNotificationPluginObject->showNotification();       //当动画展开时给插件一个通知
-    }
 
     int  AnimaStartSideBarSite[4];                           //侧边栏动画开始位置
     int  AnimaStopSidebarSite[4];                            //侧边栏动画结束位置
-    switch (getPanelSite())
+    int clipboardhight = setClipBoardWidgetScaleFactor();
+    sidebarPluginsWidgets::getInstancePluinsWidgets()->setClipboardWidgetSize(clipboardhight);      //设定剪贴板高度
+    m_pPeonySite = getPanelSite();
+    switch (m_pPeonySite)
     {
         case Widget::PanelDown :
             {
@@ -374,7 +377,7 @@ void Widget::showAnimation()
         case Widget::PanelLeft:
             {
                 //起始位置的坐标
-                AnimaStartSideBarSite[0] = 400;
+                AnimaStartSideBarSite[0] = -400;
                 AnimaStartSideBarSite[1] = 0;
                 AnimaStartSideBarSite[2] = 400;
                 AnimaStartSideBarSite[3] = m_nScreenHeight;
@@ -408,21 +411,36 @@ void Widget::showAnimation()
     m_pAnimationShowSidebarWidget->start();
 }
 
-void Widget::updateAnimationPosition(int x1, int y1, int x2, int y2)
-{
-    this->setGeometry(x1, y1, m_nInitalXPosition - x1, y2);
-    m_pMainOuterReplaceWidget->setFixedSize(m_nInitalXPosition - x1, y2);
-}
-
-void Widget::showAnimationFinish()
-{
-}
-
 void Widget::showAnimationAction(const QVariant &value)
 {
     QRect Rect = value.value<QRect>();
     int x = Rect.x();
-    mostGrandWidget::getInstancemostGrandWidget()->setProperty("blurRegion", QRegion(QRect(x, 0, 400, m_nScreenHeight - connectTaskBarDbus())));
+    if (m_pPeonySite == Widget::PanelDown
+          || m_pPeonySite == Widget::PanelUp) {
+        mostGrandWidget::getInstancemostGrandWidget()->setProperty("blurRegion", QRegion(QRect(x, 0, 400, m_nScreenHeight - connectTaskBarDbus())));
+    } else {
+        mostGrandWidget::getInstancemostGrandWidget()->setProperty("blurRegion", QRegion(QRect(x, 0, 400, m_nScreenHeight)));
+    }
+}
+
+void Widget::showAnimationFinish()
+{
+    if (m_bfinish) {
+        mostGrandWidget::getInstancemostGrandWidget()->topLevelWidget()->setProperty("blurRegion", QRegion(QRect(1, 1, 1, 1)));
+        hideAnimation();
+        m_bfinish = false;
+    }
+    return;
+}
+
+/* 获取Getting值 */
+void sidebarPluginsWidgets::getTransparencyValue(const QString key)
+{
+    if (key == "transparency") {
+        tranSparency = m_pTransparency->get("transparency").toFloat();
+        qDebug() << "获取到的值为----->" << tranSparency;
+    }
+    return;
 }
 
 //隐藏动画
@@ -430,10 +448,8 @@ void Widget::hideAnimation()
 {
     m_bShowFlag = false;
     NotificationInterface* pNotificationPluginObject = qobject_cast<NotificationInterface*>(m_pNotificationPluginObject);
-    if(nullptr != pNotificationPluginObject)
-    {
+    if (nullptr != pNotificationPluginObject)
         pNotificationPluginObject->hideNotification();      //当动画隐藏时给插件一个通知
-    }
 
     int  AnimaStartSideBarSite[4];                          //侧边栏动画开始位置
     int  AnimaStopSidebarSite[4];                           //侧边栏动画结束位置
@@ -474,7 +490,7 @@ void Widget::hideAnimation()
                 AnimaStartSideBarSite[2] = 400;
                 AnimaStartSideBarSite[3] = m_nScreenHeight;
                 //结束位置坐标
-                AnimaStopSidebarSite[0]  = 450;
+                AnimaStopSidebarSite[0]  = -400;
                 AnimaStopSidebarSite[1]  = 0;
                 AnimaStopSidebarSite[2]  = 400;
                 AnimaStopSidebarSite[3]  = m_nScreenHeight;
@@ -501,50 +517,34 @@ void Widget::hideAnimation()
     m_pAnimationHideSidebarWidget->setStartValue(QRect(AnimaStartSideBarSite[0], AnimaStartSideBarSite[1], AnimaStartSideBarSite[2], AnimaStartSideBarSite[3]));
     m_pAnimationHideSidebarWidget->setEndValue(QRect(AnimaStopSidebarSite[0], AnimaStopSidebarSite[1], AnimaStopSidebarSite[2], AnimaStopSidebarSite[3]));
     m_pAnimationHideSidebarWidget->start();
+    return;
 }
 
 void Widget::hideAnimationFinish()
 {
     mostGrandWidget::getInstancemostGrandWidget()->hide();
-}
-
-//当改变屏幕分辨率时重新获取屏幕分辨率
-void Widget::onResolutionChanged(int argc)
-{
-    Q_UNUSED(argc);
-    GetsAvailableAreaScreen();                               //获取屏幕可用高度区域
-    ModifyScreenNeeds();
     return;
 }
 
-/* 修改屏幕分辨率或者主屏需要做的事情 */
-void Widget::ModifyScreenNeeds()
+//当改变屏幕分辨率时重新获取屏幕分辨率
+void Widget::onResolutionChanged(const QRect argc)
 {
-    int clipboardhight = setClipBoardWidgetScaleFactor();
-
-    qDebug() << "剪贴板高度" << clipboardhight;
-    sidebarPluginsWidgets::getInstancePluinsWidgets()->setClipboardWidgetSize(clipboardhight); //设定剪贴板高度
-
-    /* 先将侧边栏show出来，改变一次状态机，将修改分辨率后，对布局的影响去掉 */
-    mostGrandWidget::getInstancemostGrandWidget()->setMostGrandwidgetCoordinates(-500, 0);
-    mostGrandWidget::getInstancemostGrandWidget()->show();
-
-    if (sidebarPluginsWidgets::getInstancePluinsWidgets()->m_statusFlag == KYLIN_STATE_CLIPBOARD) {
-        sidebarPluginsWidgets::getInstancePluinsWidgets()->m_pSidebarPluginButton->SendSingal();
-        sidebarPluginsWidgets::getInstancePluinsWidgets()->m_pClipboardButton->SendSingal();
-        sidebarPluginsWidgets::getInstancePluinsWidgets()->ClipBoardBool = true;
-    } else if (sidebarPluginsWidgets::getInstancePluinsWidgets()->m_statusFlag == KYLIN_STATE_SMALL_PLUGINS) {
-        sidebarPluginsWidgets::getInstancePluinsWidgets()->m_pClipboardButton->SendSingal();
-        sidebarPluginsWidgets::getInstancePluinsWidgets()->m_pSidebarPluginButton->SendSingal();
-        sidebarPluginsWidgets::getInstancePluinsWidgets()->SmallPluginsBool = true;
-    }
+    Q_UNUSED(argc);
+    qDebug() << "屏幕分辨率发生变化";
+    GetsAvailableAreaScreen();                               //获取屏幕可用高度区域
+    ModifyScreenNeeds();                                     //修改屏幕分辨率或者主屏需要做的事情
+    InitializeHomeScreenGeometry();
+    return;
 }
 
 /* 主屏发生变化槽函数 */
 void Widget::primaryScreenChangedSLot()
 {
+    qDebug() << "主屏发生变化";
     GetsAvailableAreaScreen();
+    ModifyScreenNeeds();
     InitializeHomeScreenGeometry();
+    return;
 }
 
 /* 屏幕数量改变时对应槽函数 */
@@ -553,7 +553,60 @@ void Widget::screenCountChangedSlots(int count)
     Q_UNUSED(count);
     qDebug() << "屏幕数量发生变化";
     GetsAvailableAreaScreen();
+    ModifyScreenNeeds();
     InitializeHomeScreenGeometry();
+    return;
+}
+
+/* 接受剪贴板信号，将boll值m_bClipboardFlag置为false; */
+void Widget::ClipboardShowSlots()
+{
+    m_bClipboardFlag = false;
+    return;
+}
+
+/* 接受剪贴板信号，将boll值m_bClipboardFlag置为true; */
+void Widget::ClipboardHideSlots()
+{
+    m_bClipboardFlag = true;
+    return;
+}
+
+/* 接受任务栏点击信号，当任务栏点击左键时，关闭任务栏 */
+void Widget::ClickPanelHideSidebarSlots()
+{
+    mostGrandWidget::getInstancemostGrandWidget()->topLevelWidget()->setProperty("blurRegion", QRegion(QRect(1, 1, 1, 1)));
+    hideAnimation();
+    return;
+}
+
+/* 右键菜单打开侧边栏槽函数 */
+void Widget::OpenSidebarSlots()
+{
+    mostGrandWidget::getInstancemostGrandWidget()->hide();
+    MostGrandWidgetCoordinates();
+    mostGrandWidget::getInstancemostGrandWidget()->show();
+    showAnimation();
+    m_bShowFlag = true;
+    setIcon(QIcon::fromTheme("kylin-tool-box", QIcon(TRAY_ICON)));
+    return;
+}
+
+/* 打开控制中心的通知中心 */
+void Widget::OpenControlCenterSettings()
+{
+    QProcess p(0);
+    p.startDetached("ukui-control-center -n");
+    p.waitForStarted();
+    return;
+}
+
+/* 修改屏幕分辨率或者主屏需要做的事情 */
+void Widget::ModifyScreenNeeds()
+{
+    int clipboardhight = setClipBoardWidgetScaleFactor();
+    sidebarPluginsWidgets::getInstancePluinsWidgets()->setClipboardWidgetSize(clipboardhight); //设定剪贴板高度
+    return;
 }
 
 /* 初始化主屏的X坐标 */
@@ -562,12 +615,15 @@ void Widget::InitializeHomeScreenGeometry()
     QList<QScreen*> screen = QGuiApplication::screens();
     int count = m_pDeskWgt->screenCount();
     if (count > 1) {
-        m_nScreen_x = screen[0]->availableGeometry().x();
-        m_nScreen_y = screen[0]->availableGeometry().y();
+        m_nScreen_x = screen[0]->geometry().x();
+        m_nScreen_y = screen[0]->geometry().y();
+
     } else {
         m_nScreen_x = 0;
         m_nScreen_y = 0;
     }
+    qDebug() << "偏移的x坐标" << m_nScreen_x;
+    qDebug() << "偏移的Y坐标" << m_nScreen_y;
 }
 
 /* 根据任务栏位置调整侧边栏位置 */
@@ -578,24 +634,31 @@ void Widget::MostGrandWidgetCoordinates()
             {
                 mostGrandWidget::getInstancemostGrandWidget()->setMostGrandwidgetSize(400, m_nScreenHeight - connectTaskBarDbus());
                 mostGrandWidget::getInstancemostGrandWidget()->setMostGrandwidgetCoordinates(m_nScreen_x + m_nScreenWidth - 400, m_nScreen_y);
+                qDebug() << "m_nScreen_x + m_nScreenWidth - 400-->" << m_nScreen_x + m_nScreenWidth - 400 << "&&" << m_nScreen_x << "&&" << m_nScreenWidth;
+                emit m_pSidebarSignal->ClipboardPreviewSignal(400, m_nScreenHeight, m_nScreen_x + m_nScreenWidth - 400, m_nScreen_y, connectTaskBarDbus());
             }
             break;
         case Widget::PanelUp:
             {
                 mostGrandWidget::getInstancemostGrandWidget()->setMostGrandwidgetSize(400, m_nScreenHeight - connectTaskBarDbus());
                 mostGrandWidget::getInstancemostGrandWidget()->setMostGrandwidgetCoordinates(m_nScreen_x + m_nScreenWidth - 400, connectTaskBarDbus() + m_nScreen_y);
+                emit m_pSidebarSignal->ClipboardPreviewSignal(400, m_nScreenHeight, m_nScreen_x + m_nScreenWidth - 400, connectTaskBarDbus() + m_nScreen_y, connectTaskBarDbus());
             }
             break;
         case Widget::PanelLeft:
             {
                 mostGrandWidget::getInstancemostGrandWidget()->setMostGrandwidgetSize(400, m_nScreenHeight);
-                mostGrandWidget::getInstancemostGrandWidget()->setMostGrandwidgetCoordinates(m_nScreen_x + m_nScreenWidth - 400, m_nScreen_y);
+                mostGrandWidget::getInstancemostGrandWidget()->setMostGrandwidgetCoordinates(m_nScreen_x + connectTaskBarDbus(), m_nScreen_y);
+                emit m_pSidebarSignal->ClipboardPreviewSignal(400, m_nScreenHeight, m_nScreen_x + connectTaskBarDbus() + 400 + 260, m_nScreen_y, 0);
+                qDebug() << "当前 m_nScreen_x + m_nScreenWidth + connectTaskBarDbus()--》" << m_nScreen_x + connectTaskBarDbus() << "m_nScreen_y ----> "  << m_nScreen_y;
+
             }
             break;
         case Widget::PanelRight:
             {
                 mostGrandWidget::getInstancemostGrandWidget()->setMostGrandwidgetSize(400, m_nScreenHeight);
                 mostGrandWidget::getInstancemostGrandWidget()->setMostGrandwidgetCoordinates(m_nScreen_x + m_nScreenWidth - 400 - connectTaskBarDbus(), m_nScreen_y);
+                emit m_pSidebarSignal->ClipboardPreviewSignal(400, m_nScreenHeight, m_nScreen_x + m_nScreenWidth - 400 - connectTaskBarDbus(), m_nScreen_y, 0);
             }
             break;
         default:
@@ -603,54 +666,41 @@ void Widget::MostGrandWidgetCoordinates()
     }
 }
 
-
 //当没展开时，来了新通知才提示
 void Widget::onNewNotification()
 {
-    if(false == m_bShowFlag)
-    {
-        m_bFwinkleFlag = true;
-        m_pTimer->start(500);
+    if (false == m_bShowFlag) {
+        setIcon(QIcon::fromTheme("kylin-tool-box-null", QIcon(TRAY_NULL_ICON)));
     }
     return;
 }
 
-void Widget::twinkle()
+/* 切换主题时，定时器槽函数 */
+void Widget::updateSmallPluginsClipboardWidget()
 {
-    if(true == m_bFwinkleFlag)
-    {
-        m_bFwinkleFlag = false;
-        setIcon(TRAY_NULL_ICON);
-    }
-    else
-    {
-        m_bFwinkleFlag = true;
-        setIcon(TRAY_ICON);
-    }
+    ModifyScreenNeeds();
+    m_pUpdateSmallPluginsWidget->stop();
 }
 
 /* 事件过滤器 */
 bool Widget::eventFilter(QObject *obj, QEvent *event)
 {
-    Q_UNUSED(obj);
-    Q_UNUSED(event);
-    if (obj == this)
-    {
-        if (event->type() == QEvent::WindowDeactivate && true == m_bShowFlag)
-        {
-            qDebug() << "事件类型" << event->type();
+    if (obj == this) {
+        if (event->type() == QEvent::WindowDeactivate && true == m_bShowFlag && true == m_bClipboardFlag) {
             qDebug() << "Widget::eventFilter 消失";
             mostGrandWidget::getInstancemostGrandWidget()->topLevelWidget()->setProperty("blurRegion", QRegion(QRect(1, 1, 1, 1)));
             hideAnimation();
             m_bShowFlag = false;
             return true;
         } else if (event->type() == QEvent::StyleChange) {
-            ModifyScreenNeeds();
+            m_pUpdateSmallPluginsWidget->start(200);
+            sidebarPluginsWidgets::getInstancePluinsWidgets()->setButtonFont();
+            return true;
         }
     }
 
-    if (!isActiveWindow())
-    {
+
+    if (!isActiveWindow() && true == m_bShowFlag) {
         activateWindow();
     }
     return false;
